<?php
#CMS - CMS Made Simple
#(c)2011 by Peter Orije (pedrosken@gmail.com)
#This project's homepage is: http://www.web2do.be
#
#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.

function smarty_cms_function_toggle_start($params, &$smarty)
{
	static $firstToggle = true;//only gets set one time per page
	
	if (!empty($params['title'])) {
		$title = $params['title'];
	}
	else {
		$title = '';
	}

	//sets the width of your bar and content
	if( isset($params['width']) ){		
		$width = $params['width'];
	}
	else {
		$width = '';
	}


	if ($params['status'] == "active" || $params['status'] == "Active" ) {
		$status = "active";
	}
	else {
		$status = '';
	}


	if ($firstToggle) {
		echo '<link rel="stylesheet" href="../lib/toggle/stylesheet.php?wd='.$width.'"  type="text/css" />';
                
		echo '<script type="text/javascript">
                    /******** Load jQuery if not present *********/
                    if (typeof jQuery === "undefined" || jQuery.fn.jquery !== \'1.4.2\') {
                            var script_tag = document.createElement(\'script\');
                            script_tag.setAttribute("type","text/javascript");
                            script_tag.setAttribute("src", "http://ajax.googleapis.com/ajax/libs/jquery/1.4.2/jquery.min.js")
                            script_tag.onload = main; //Run main() once jQuery has loaded
                            script_tag.onreadystatechange = function () { //Same thing but for IE
                                    if (this.readyState == \'complete\' || this.readyState == \'loaded\') main();
                            } //onreadystatechange.function
                            document.getElementsByTagName("head")[0].appendChild(script_tag);
                            } else {
                                    main();
                    } //if.jQuery

                    function main() {
                            $(document).ready(function() {
                                    $(".toggle_container").hide();
                                    $(".active").slideToggle("slow,");
                                    $(".active").prev("h2.trigger").addClass("active"); 

                                    /*$("h2.trigger").toggle(function(){
                                            $(this).addClass("active"); 
                                            }, function () {
                                            $(this).removeClass("active");
                                    });*/

                                    $("h2.trigger").click(function(){		
                                            $(this).next(".toggle_container").slideToggle("slow,");

                                            if ($(this).hasClass("active")){
                                                    $(this).removeClass("active");
                                            }else{
                                                    //toggle all other open containers first
                                                    $(".active").next(".toggle_container").slideToggle("slow,");
                                                    $(".active").removeClass("active");

                                                    $(this).addClass("active"); 
                                            }
                                    });
                            });
                    } //function.main
                    </script>'
		;

		
		
		
		$firstToggle = false;
	}
	
	echo '<h2 class="trigger">'.$title.'</h2>
	<div class="toggle_container '.$status.'">
		<div class="block">
			';
	
	
}

function smarty_cms_help_function_toggle_start() {
	?>
	<h3>What does this do?</h3>
	<p>It creates a div (&quot;block&quot;) witch can collapse and expand by pressing the bar, it uses JQuery.<br />
	You can view a demo here : <a href="http://www.web2do.be/content_toggle" target="_blank">DEMO</a>
</p>
		<h3>How do I use it?</h3>
<p>Just insert the tag into your content or template like: <code>{toggle_start title="text line for the top bar"}</code><br />
  and close it with <code>{toggle_end}</code><br />
  <br />
  <strong>For example 1:</strong><br />
  <code>
  {toggle_start title=&quot;Web Design &amp; Development&quot;}<br />
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;HTML code like pictures, text, place them here ...<br />
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;...<br />
  {toggle_end}<br /> 
  <br />
</code>
  (this 'll output an closed window from 625 pixels width)
<br />
<br />

  <strong>For example 2:</strong><br />
  <code>
  {toggle_start status=&quot;active&quot; width=&quot;750&quot; title=&quot;Web Design &amp; Development&quot;}<br />
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;HTML code like pictures, text, place them here ...<br />
&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;...<br />
  {toggle_end}<br /> 
  <br />
</code>
  (this 'll output an open window from 720 pixels width)



</p>
<h3>The result: </h3>
<img src="../lib/toggle/sample2.gif" /><br />
<br />
For personal changes you can edit the top bar (trigger.gif)
like this example:<br />
<img src="../lib/toggle/sample.gif" /><br />

  
<p>&nbsp;</p>
<h3>TinyMCE option:</h3>
<p><u>For easy use, you can edit TinyMCE (optional)</u><br />
  goto admin / Extentsions /TinyMce WYSIWYG<br />
open tab Advanced, scroll down and edit &quot;Custom dropdown:&quot;</p>
<p>add this code or change original:<br />
    <textarea class="pagesmalltextarea" style="height: 80px;">
  ---|---
  Start expand/collapse-area|{toggle_start title=\'This is my expandable area\'}
  End expand/collapse-area|{toggle_end}
  ---|---
    </textarea>
</p>
<p>and save<br />
  now you can use the icon &quot;Specifik Dropdown-menu&quot; in TinyMCE menubar.</p>
<p>&nbsp; </p>
<h3>Parameters</h3>
<ul>
  <li><em>(optional)</em> title=&quot;some text here&quot; - Display title in the bar.</li>
  <li><em>(optional)</em> status=&quot;active&quot; - This 'll show the content, if omitted the content 'll be collapsed by default.</li>
  <li><em>(optional)</em> width=&quot;700&quot; - Controls the width of your content.<br />
		if not set then default width = 625px;<br />
		<span style="color:red;">Warning</span>: when using multiple content toggle windows it only needs to be set in the first toggle difenition. Else this setting won't work. </li>
  
</ul>
<p>&nbsp;</p>

done... 
	  <?php
}



function smarty_cms_about_function_toggle_start() {
	?>
      
<p>Author: Peter Orije <a href="http://www.web2do.be">www.web2do.be/content_toggle</a></p>
	<p>Version: 1.3	</p>
   <p>&nbsp;</p>

 <?php
}

?>
